@@ -1,5 +1,5 @@
 /* snac - A simple, minimalistic ActivityPub instance */
-/* copyright (c) 2022 - 2024 grunfink et al. / MIT license */
+/* copyright (c) 2022 - 2025 grunfink et al. / MIT license */
 
 #include "xs.h"
 #include "xs_hex.h"
@@ -319,7 +319,8 @@ int user_persist(snac *snac, int publish)
 
             if (old != NULL) {
                 int nw = 0;
-                const char *fields[] = { "header", "avatar", "name", "bio", "metadata", NULL };
+                const char *fields[] = { "header", "avatar", "name", "bio",
+                                         "metadata", "latitude", "longitude", NULL };
 
                 for (int n = 0; fields[n]; n++) {
                     const char *of = xs_dict_get(old, fields[n]);
@@ -336,6 +337,10 @@ int user_persist(snac *snac, int publish)
 
                 if (!nw)
                     publish = 0;
+                else {
+                    /* uncache the actor object */
+                    object_del(snac->actor);
+                }
             }
         }
     }
@@ -674,6 +679,37 @@ int index_desc_first(FILE *f, char md5[MD5_HEX_SIZE], int skip)
     return 1;
 }
 
+int index_asc_first(FILE *f,char md5[MD5_HEX_SIZE], const char *seek_md5)
+/* reads the first entry of an ascending index, starting from a given md5 */
+{
+    fseek(f, SEEK_SET, 0);
+    while (fread(md5, MD5_HEX_SIZE, 1, f)) {
+        md5[MD5_HEX_SIZE - 1] = '\0';
+        if (strcmp(md5,seek_md5) == 0) {
+            return index_asc_next(f, md5);
+        }
+    }
+    return 0;
+}
+
+int index_asc_next(FILE *f, char md5[MD5_HEX_SIZE])
+/* reads the next entry of an ascending index */
+{
+    for (;;) {
+        /* read an md5 */
+        if (!fread(md5, MD5_HEX_SIZE, 1, f))
+            return 0;
+
+        /* deleted, skip */
+        if (md5[0] != '-')
+            break;
+    }
+
+    md5[MD5_HEX_SIZE - 1] = '\0';
+
+    return 1;
+}
+
 
 xs_list *index_list_desc(const char *fn, int skip, int show)
 /* returns an index as a list, in reverse order */
